window.Gleam.initSearch([{"doc":"directories","title":"directories","content":"# directories\n\nA lightweight gleam package to get standard locations of directories for temporary files, config, cache, etc.\n\n\n[![Package Version](https://img.shields.io/hexpm/v/directories)](https://hex.pm/packages/directories)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/directories/)\n\n```sh\ngleam add directories@1\n```\n```gleam\nimport directories\n\npub fn main() {\n  // All functions return an Result(String, Nil)\n  // Nil will be returned whenever it couldn&#39;t find a valid directory\n  let tmp_dir = io.debug(directories.tmp_dir())\n  let home_dir = io.debug(directories.home_dir())\n  let cache_dir = io.debug(directories.cache_dir())\n  let config_dir = io.debug(directories.config_dir())\n  let config_local_dir = io.debug(directories.config_local_dir())\n  let data_dir = io.debug(directories.data_dir())\n  let data_local_dir = io.debug(directories.data_local_dir())\n  let executable_dir = io.debug(directories.executable_dir())\n  let preferences_dir = io.debug(directories.preferences_dir())\n  let runtime_dir = io.debug(directories.runtime_dir())\n  let state_dir = io.debug(directories.state_dir())\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/directories&gt;.\n\n## Dependencies\n- It depends on `gleam_stdlib`\n- It depends on `platform` to find out what is the host operating system.\n- It depends on `simplifile` to check if a folder exists and is a valid file\n- It depends on `envoy` to get environment variables\n\n## TODO\n- [x] Publish to hexpm\n- [x] Remove dependency on `gleam_erlang` to make it work in the js runtime\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"directories","title":"cache_dir","content":"pub fn cache_dir() -&gt; Result(String, Nil)\n Returns the path to the user-specific cache directory\n \n On Windows, it&#39;ll return the value of `%APPDATA%` if it exists\n \n On MacOS, it&#39;ll return value of `$HOME/Library/Caches` if it exists\n \n On Linux and FreeBSD, it&#39;ll check `$XDG_CACHE_HOME` and `$HOME/.cache`, returning the first one that is a valid directory\nSynonyms:\ndirectories.cache_dir\ndirectories cache_dir","url":"directories.html#cache_dir"},{"doc":"directories","title":"config_dir","content":"pub fn config_dir() -&gt; Result(String, Nil)\n Returns the path to the user-specific config directory. This directory may be synced across computers\n \n On Windows, it&#39;ll return the value of `%APPDATA%` if it exists\n \n On MacOS, it&#39;ll return the value of `$HOME/Library/Application Support` if it exists\n \n On Linux and FreeBSD, it&#39;ll check `$XDG_CONFIG_HOME` and `$HOME/.config`, returning the first one that is a valid directory\nSynonyms:\ndirectories.config_dir\ndirectories config_dir","url":"directories.html#config_dir"},{"doc":"directories","title":"config_local_dir","content":"pub fn config_local_dir() -&gt; Result(String, Nil)\n Returns the path to the user-specific local config directory. Similar to `config_dir`, except Windows won&#39;t sync it when connected to a domain with a roaming profile\n \n On Windows, it&#39;ll return the value of `%LOCALAPPDATA%` if it exists\n \n On MacOS, it&#39;ll return the value of `$HOME/Library/Application Support` if it exists\n \n On Linux and FreeBSD, it&#39;ll check `$XDG_CONFIG_HOME` and `$HOME/.config`, returning the first one that is a valid directory\nSynonyms:\ndirectories.config_local_dir\ndirectories config_local_dir","url":"directories.html#config_local_dir"},{"doc":"directories","title":"data_dir","content":"pub fn data_dir() -&gt; Result(String, Nil)\n Returns the path to the user-specific data directory. This directory may be synced across computers\n \n On Windows, it&#39;ll return the value of `%APPDATA%` if it exists\n \n On MacOS, it&#39;ll return the value of `$HOME/Library/Application Support` if it exists\n \n On Linux and FreeBSD, it&#39;ll check `$XDG_DATA_HOME``and $HOME/.local/share, returning the first one that is a valid directory\nSynonyms:\ndirectories.data_dir\ndirectories data_dir","url":"directories.html#data_dir"},{"doc":"directories","title":"data_local_dir","content":"pub fn data_local_dir() -&gt; Result(String, Nil)\n Returns the path to the user-specific data directory. Similar to `data_dir`, except Windows won&#39;t sync it when connected to a domain with a roaming profile\n \n On Windows, it&#39;ll return the value of `%LOCALAPPDATA%` if it exists\n \n On MacOS, it&#39;ll return the value of `$HOME/Library/Application Support` if it exists\n \n On Linux and FreeBSD, it&#39;ll check DG_DATA_HOME $H``ocal/share, rg the first one that is a valid directory\nSynonyms:\ndirectories.data_local_dir\ndirectories data_local_dir","url":"directories.html#data_local_dir"},{"doc":"directories","title":"executable_dir","content":"pub fn executable_dir() -&gt; Result(String, Nil)\n Returns the path to which user-specific executable files may be written. \n \n On Linux and FreeBSD, it&#39;ll check $XDG_BIN_HOME, $HOME/.local/bin, $XDG_DATA_HOME/../bin and return the first one that is a valid directory\n \n On all other platforms, it&#39;ll always return `Error(Nil)`\nSynonyms:\ndirectories.executable_dir\ndirectories executable_dir","url":"directories.html#executable_dir"},{"doc":"directories","title":"home_dir","content":"pub fn home_dir() -&gt; Result(String, Nil)\n Returns the path to the user&#39;s home directory\n \n It&#39;ll check `%UserProfile%` and `%Profile%` on windows, returning first one that is a valid directory\n \n On MacOS, Linux, and FreeBSD, it&#39;ll return the value of `$HOME` if it exists\nSynonyms:\ndirectories.home_dir\ndirectories home_dir","url":"directories.html#home_dir"},{"doc":"directories","title":"main","content":"pub fn main() -&gt; Result(String, Nil)\n\nSynonyms:\ndirectories.main\ndirectories main","url":"directories.html#main"},{"doc":"directories","title":"preference_dir","content":"pub fn preference_dir() -&gt; Result(String, Nil)\n Returns the path to the user-specific preferences directory. This directory may be synced across computers\n \n On Windows, it&#39;ll return the value of `%APPDATA%` if it exists\n \n On MacOS, it&#39;ll return the value of `$HOME/Library/Preferences` if it exists\n \n On Linux and FreeBSD, it&#39;ll check $XDG_CONFIG_HOME and $HOME/.config, returning the first one that is a valid directory\nSynonyms:\ndirectories.preference_dir\ndirectories preference_dir","url":"directories.html#preference_dir"},{"doc":"directories","title":"runtime_dir","content":"pub fn runtime_dir() -&gt; Result(String, Nil)\n Returns the path to which user-specific runtime files and other file objects may be placed. \n \n On Linux and FreeBSD, it&#39;ll check $XDG_RUNTIME_DIR if it is a valid directory\n \n On all other platforms, it&#39;ll always return `Error(Nil)`\nSynonyms:\ndirectories.runtime_dir\ndirectories runtime_dir","url":"directories.html#runtime_dir"},{"doc":"directories","title":"state_dir","content":"pub fn state_dir() -&gt; Result(String, Nil)\n Returns the path to which user-specific state may be stored. \n \n The state directory contains data that should be retained between sessions (unlike the runtime directory), \n but may not be important/portable enough to be synchronized across machines (unlike the config/preferences/data directories).\n \n On Linux and FreeBSD, it&#39;ll check $XDG_STATE_HOME and $HOME/.local/state, returning the first one that is a valid directory\n \n On all other platforms, it&#39;ll always return `Error(Nil)`\nSynonyms:\ndirectories.state_dir\ndirectories state_dir","url":"directories.html#state_dir"},{"doc":"directories","title":"tmp_dir","content":"pub fn tmp_dir() -&gt; Result(String, Nil)\n Returns the path to a temporary directory\n \n It&#39;ll first check `%TMPDIR%`, `%TEMP%`, `%TMP%`, and return the first one that is a valid directory\n \n If that fails, It&#39;ll check `C:\\TEMP`, `C:\\TMP`, `\\TEMP`, `\\TMP` on windows.\n \n On MacOS, Linux, and FreeBSD, it&#39;ll check `/tmp`, `/var/tmp`, `/usr/tmp`,\nSynonyms:\ndirectories.tmp_dir\ndirectories tmp_dir","url":"directories.html#tmp_dir"},{"doc":"directories","title":"directories","content":"","url":"directories.html"}]);